@@ -1,6 +1,7 @@
+import errno
 import os
 import sys
-import errno
+import urlparse
 from . import user_settings
 
 def ensure_directory(path):
@@ -33,9 +34,12 @@ ADMINS = USER_SETTINGS['ADMINS']
 TIME_ZONE = USER_SETTINGS['TIME_ZONE']
 LANGUAGE_CODE = USER_SETTINGS['LANGUAGE_CODE']
 ALLOW_VERSION_OVERWRITE = USER_SETTINGS['ALLOW_VERSION_OVERWRITE']
+USE_HTTPS = USER_SETTINGS['USE_HTTPS']
 
 MANAGERS = ADMINS
 
+ALLOWED_HOSTS = ['*']
+
 DATABASES = {
     'default': {
         'ENGINE': 'django.db.backends.sqlite3',
@@ -80,8 +84,8 @@ ROOT_URLCONF = 'djangopypi2.website.urls'
 
 WSGI_APPLICATION = 'djangopypi2.website.wsgi.application'
 
-LOGIN_URL = '/users/login/'
-LOGOUT_URL = '/users/logout/'
+LOGIN_URL = '/accounts/login/'
+LOGOUT_URL = '/accounts/logout/'
 LOGIN_REDIRECT_URL = '/'
 
 TEMPLATE_CONTEXT_PROCESSORS = [
@@ -89,6 +93,12 @@ TEMPLATE_CONTEXT_PROCESSORS = [
     'django.core.context_processors.request',
 ]
 
+WEBSITE_ROOT = os.path.dirname(os.path.realpath(__file__))
+
+TEMPLATE_DIRS = (
+    os.path.join(WEBSITE_ROOT, 'templates'),
+)
+
 INSTALLED_APPS = (
     'django.contrib.auth',
     'django.contrib.contenttypes',
@@ -97,6 +107,7 @@ INSTALLED_APPS = (
     'django.contrib.messages',
     'django.contrib.staticfiles',
     'django.contrib.admin',
+    'registration',
     'djangopypi2.apps.pypi_ui',
     'djangopypi2.apps.pypi_users',
     'djangopypi2.apps.pypi_manage',
@@ -105,6 +116,21 @@ INSTALLED_APPS = (
     'djangopypi2.apps.pypi_frontend',
 )
 
+ACCOUNT_ACTIVATION_DAYS = 7
+
+email_server = urlparse.urlparse(USER_SETTINGS['EMAIL_SERVER'])
+EMAIL_HOST = email_server.hostname or 'localhost'
+EMAIL_PORT = email_server.port or '1025'
+EMAIL_HOST_USER = email_server.username or ''
+EMAIL_HOST_PASSWORD = email_server.password or ''
+
+EMAIL_USE_TLS = USER_SETTINGS['EMAIL_USE_TLS']
+DEFAULT_FROM_EMAIL = USER_SETTINGS['EMAIL_DEFAULT_SENDER']
+
+if USE_HTTPS:
+    SESSION_COOKIE_SECURE = True
+    CSRF_COOKIE_SECURE = True
+
 LOGGING = {
     'version': 1,
     'disable_existing_loggers': False,
